@@ -251,7 +251,7 @@ module Init : sig
   val conf_daemon : bool Conf.t
   val conf_daemon_pidfile : bool Conf.t
   val conf_daemon_pidfile_path : string Conf.t
-  val conf_concurrent : bool Conf.t
+  val conf_daemon_pidfile_perms : int Conf.t
   val conf_trace : bool Conf.t
   val conf_catch_exn : bool Conf.t
 
@@ -267,6 +267,7 @@ module Log : sig
     *)
   type t =
     < active : int -> bool
+    ; path : Conf.path
     ; f : 'a. int -> ('a, unit, string, unit) format4 -> 'a >
 
   type custom_log = { timestamp : bool; exec : string -> unit }
