@@ -376,6 +376,11 @@ module Init = struct
   let conf_daemon_pidfile_path =
     Conf.string ~p:(conf_daemon_pidfile#plug "path") "path to pidfile"
 
+  let conf_daemon_pidfile_perms =
+    Conf.int ~d:0o640
+      ~p:(conf_daemon_pidfile#plug "perms")
+      "Unix file permissions for pidfile. Default: `0o640`."
+
   let conf_daemon_drop_user =
     Conf.bool
       ~p:(conf_daemon#plug "change_user")
@@ -394,10 +399,6 @@ module Init = struct
   let conf_trace =
     Conf.bool ~p:(conf#plug "trace") ~d:false "dump an initialization trace"
 
-  let conf_concurrent =
-    Conf.bool ~p:(conf#plug "concurrent") ~d:false
-      "run initialization using concurrent threads"
-
   let conf_catch_exn =
     Conf.bool ~p:(conf#plug "catch_exn") ~d:true
       "catch exceptions, use false to backtrace exceptions"
@@ -448,13 +449,13 @@ module Init = struct
           a.launched <- true;
           log "start";
           log "start-depends";
-          mult_exec a.depends;
+          List.iter exec a.depends;
           log "stop-depends";
           log "start-atom";
           a.f ();
           log "stop-atom";
           log "start-triggers";
-          mult_exec a.triggers;
+          List.iter exec a.triggers;
           log "stop-triggers";
           log "stop"
         end;
@@ -463,16 +464,6 @@ module Init = struct
       with e ->
         Mutex.unlock a.mutex;
         raise e
-    and mult_exec l =
-      match conf_concurrent#get with
-        | true ->
-            let ask x =
-              log (Printf.sprintf "exec %s" x.name);
-              Thread.create exec x
-            in
-            let threads = List.map ask l in
-            List.iter Thread.join threads
-        | false -> List.iter exec l
     in
     exec a
 
@@ -566,7 +557,11 @@ module Init = struct
     if conf_daemon_pidfile#get then begin
       (* Write PID to file *)
       let filename = conf_daemon_pidfile_path#get in
-      let f = open_out filename in
+      let f =
+        open_out_gen
+          [Open_wronly; Open_creat; Open_trunc]
+          conf_daemon_pidfile_perms#get filename
+      in
       let pid = Unix.getpid () in
       output_string f (string_of_int pid);
       output_char f '\n';
@@ -623,9 +618,9 @@ module Init = struct
   let args =
     if Sys.os_type <> "Win32" then
       [
-        ( ["--daemon"; "-d"],
+        ( ["-d"; "--daemon"],
           Arg.Unit (fun () -> conf_daemon#set true),
-          "run in daemon mode" );
+          "Run in daemon mode." );
       ]
     else []
 end
@@ -633,6 +628,7 @@ end
 module Log = struct
   type t =
     < active : int -> bool
+    ; path : Conf.path
     ; f : 'a. int -> ('a, unit, string, unit) format4 -> 'a >
 
   type custom_log = { timestamp : bool; exec : string -> unit }
@@ -770,6 +766,8 @@ module Log = struct
     object (self : t)
       val label = fun lvl -> "[" ^ path_str ^ ":" ^ string_of_int lvl ^ "]"
 
+      method path = path
+
       method active lvl =
         let rec aux l =
           match l with
@@ -787,7 +785,10 @@ module Log = struct
         match self#active lvl with
           | true ->
               let time = Unix.gettimeofday () in
-              Printf.ksprintf (fun s -> proceed (time, label lvl ^ " " ^ s))
+              Printf.ksprintf (fun s ->
+                  List.iter
+                    (fun s -> proceed (time, label lvl ^ " " ^ s))
+                    (String.split_on_char '\n' s))
           | false -> Printf.ksprintf (fun _ -> ())
     end
 
